import type * as Errors from './Errors.js';
/**
 * Parses a JSON string, with support for `bigint`.
 *
 * @example
 * ```ts twoslash
 * import { Json } from 'ox'
 *
 * const json = Json.parse('{"foo":"bar","baz":"69420694206942069420694206942069420694206942069420#__bigint"}')
 * // @log: {
 * // @log:   foo: 'bar',
 * // @log:   baz: 69420694206942069420694206942069420694206942069420n
 * // @log: }
 * ```
 *
 * @param string - The value to parse.
 * @param reviver - A function that transforms the results.
 * @returns The parsed value.
 */
export declare function parse(string: string, reviver?: ((this: any, key: string, value: any) => any) | undefined): any;
export declare namespace parse {
    var parseError: (error: unknown) => parse.ErrorType;
}
export declare namespace parse {
    type ErrorType = Errors.GlobalErrorType;
}
/**
 * Stringifies a value to its JSON representation, with support for `bigint`.
 *
 * @example
 * ```ts twoslash
 * import { Json } from 'ox'
 *
 * const json = Json.stringify({
 *   foo: 'bar',
 *   baz: 69420694206942069420694206942069420694206942069420n,
 * })
 * // @log: '{"foo":"bar","baz":"69420694206942069420694206942069420694206942069420#__bigint"}'
 * ```
 *
 * @param value - The value to stringify.
 * @param replacer - A function that transforms the results. It is passed the key and value of the property, and must return the value to be used in the JSON string. If this function returns `undefined`, the property is not included in the resulting JSON string.
 * @param space - A string or number that determines the indentation of the JSON string. If it is a number, it indicates the number of spaces to use as indentation; if it is a string (e.g. `'\t'`), it uses the string as the indentation character.
 * @returns The JSON string.
 */
export declare function stringify(value: any, replacer?: ((this: any, key: string, value: any) => any) | null | undefined, space?: string | number | undefined): string;
export declare namespace stringify {
    var parseError: (error: unknown) => stringify.ErrorType;
}
export declare namespace stringify {
    type ErrorType = Errors.GlobalErrorType;
}
//# sourceMappingURL=Json.d.ts.map